@@ -70,6 +70,60 @@ func (logicalSchema *LogicalSchema) AddStatement(stmt *Statement) error {
 	}
 }
 
+// LowerCaseNames adjusts logicalSchema in-place such that its object names are
+// forced to lower-case as appropriate for the supplied NameCaseMode.
+// An error will be returned if case-insensitivity would result in duplicate
+// objects with the same name and type.
+func (logicalSchema *LogicalSchema) LowerCaseNames(mode tengo.NameCaseMode) error {
+	switch mode {
+	case tengo.NameCaseLower: // lower_case_table_names=1
+		// Schema names and table names are forced lowercase in this mode
+		logicalSchema.Name = strings.ToLower(logicalSchema.Name)
+		newCreates := make(map[tengo.ObjectKey]*Statement, len(logicalSchema.Creates))
+		for k, stmt := range logicalSchema.Creates {
+			if k.Type == tengo.ObjectTypeTable {
+				k.Name = strings.ToLower(k.Name)
+				stmt.ObjectName = strings.ToLower(stmt.ObjectName)
+				if origStmt, already := newCreates[k]; already {
+					return DuplicateDefinitionError{
+						ObjectKey: stmt.ObjectKey(),
+						FirstFile: origStmt.File,
+						FirstLine: origStmt.LineNo,
+						DupeFile:  stmt.File,
+						DupeLine:  stmt.LineNo,
+					}
+				}
+			}
+			newCreates[k] = stmt
+		}
+		logicalSchema.Creates = newCreates
+
+	case tengo.NameCaseInsensitive: // lower_case_table_names=2
+		// Only view names are forced to lowercase in this mode, but Community Edition
+		// codebase does not support views, so nothing to lowercase here.
+		// However, with this mode we still need to ensure there aren't any duplicate
+		// table names in CREATEs after accounting for case-insensitive table naming.
+		lowerTables := make(map[string]*Statement)
+
+		for k, stmt := range logicalSchema.Creates {
+			if k.Type == tengo.ObjectTypeTable {
+				lowerName := strings.ToLower(k.Name)
+				if origStmt, already := lowerTables[lowerName]; already {
+					return DuplicateDefinitionError{
+						ObjectKey: stmt.ObjectKey(),
+						FirstFile: origStmt.File,
+						FirstLine: origStmt.LineNo,
+						DupeFile:  stmt.File,
+						DupeLine:  stmt.LineNo,
+					}
+				}
+				lowerTables[lowerName] = stmt
+			}
+		}
+	}
+	return nil
+}
+
 // ParseDir parses the specified directory, including all *.sql files in it,
 // its .skeema config file, and all .skeema config files of its parent
 // directory hierarchy. Evaluation of parent dirs stops once we hit either a
@@ -291,10 +345,10 @@ func (dir *Dir) Instances() ([]*tengo.Instance, error) {
 	// For each hostname, construct a DSN and use it to create an Instance
 	var instances []*tengo.Instance
 	for _, host := range hosts {
-		var dsn string
+		var net, addr string
 		thisPortValue := portValue
 		if host == "localhost" && (socketWasSupplied || !portWasSupplied) {
-			dsn = fmt.Sprintf("%s@unix(%s)/?%s", userAndPass, socketValue, params)
+			net, addr = "unix", socketValue
 		} else {
 			splitHost, splitPort, err := tengo.SplitHostOptionalPort(host)
 			if err != nil {
@@ -307,8 +361,9 @@ func (dir *Dir) Instances() ([]*tengo.Instance, error) {
 				host = splitHost
 				thisPortValue = splitPort
 			}
-			dsn = fmt.Sprintf("%s@tcp(%s:%d)/?%s", userAndPass, host, thisPortValue, params)
+			net, addr = "tcp", fmt.Sprintf("%s:%d", host, thisPortValue)
 		}
+		dsn := fmt.Sprintf("%s@%s(%s)/?%s", userAndPass, net, addr, params)
 		instance, err := util.NewInstance("mysql", dsn)
 		if err != nil {
 			if dir.Config.Changed("password") {
@@ -440,7 +495,17 @@ func (dir *Dir) SchemaNames(instance *tengo.Instance) (names []string, err error
 	if err != nil {
 		return nil, err
 	}
-	return filterSchemaNames(names, ignoreSchema), nil
+	names = filterSchemaNames(names, ignoreSchema)
+
+	// If the instance has lower_case_table_names=1, force result to lowercase,
+	// to handle cases where a user has manually configured a mixed-case name
+	if instance.NameCaseMode() == tengo.NameCaseLower {
+		for n, name := range names {
+			names[n] = strings.ToLower(name)
+		}
+	}
+
+	return names, nil
 }
 
 func looksLikeRegex(input string) bool {
@@ -564,17 +629,20 @@ func (dir *Dir) InstanceDefaultParams() (string, error) {
 	v.Set("writeTimeout", "5s")
 
 	// Prefer TLS, but not during integration testing
-	sslMode, err := dir.Config.GetEnum("ssl-mode", "disabled", "preferred", "required")
-	if err != nil {
-		return "", err
-	}
-	if sslMode == "disabled" || (dir.Config.IsTest && !dir.Config.Supplied("ssl-mode")) {
-		v.Set("tls", "false")
-	} else if sslMode == "required" {
-		v.Set("tls", "skip-verify")
-	} else {
-		v.Set("tls", sslMode)
+	sslMode := "preferred"
+	if dir.Config.Supplied("ssl-mode") {
+		sslMode, err = dir.Config.GetEnum("ssl-mode", "disabled", "preferred", "required")
+		if err != nil {
+			return "", err
+		} else if sslMode == "disabled" {
+			sslMode = "false" // driver uses "false" to mean mysql ssl-mode=disabled
+		} else if sslMode == "required" {
+			sslMode = "skip-verify" // driver uses "skip-verify" to mean mysql ssl-mode=required
+		}
+	} else if dir.Config.IsTest {
+		sslMode = "false"
 	}
+	v.Set("tls", sslMode)
 
 	// Set values from connect-options
 	for name, value := range options {
