@@ -1,5 +1,6 @@
-# Test edge cases of column defaults and default expressions in MariaDB 10.2+
-# and MySQL 8.0.13+.
+# Test edge cases of column defaults and default expressions in MySQL 8.0.13+.
+# (Similar table for MariaDB is split into a separate file due to lack of 4-byte
+# char support there.)
 
 SET foreign_key_checks=0;
 SET sql_log_bin=0;
@@ -12,7 +13,7 @@ CREATE TABLE testdefaults (
 	b int default (a*a),
 	c int default (abs(a)),
 	d varchar(100) default 'hello',
-	e varchar(200) default (concat(d, ' world')),
+	e varchar(200) default (concat(d, ' world 💩')) COMMENT '(stuff after default',
 	f varchar(30) NOT NULL default '',
 	g float default (rand()),
 	h float default (rand() * rand()),
@@ -21,7 +22,7 @@ CREATE TABLE testdefaults (
 	k datetime default current_timestamp,
 	l timestamp default current_timestamp(),
 	m timestamp(4) default current_timestamp(4),
-	n text default (concat(d, ' worlds')),
+	n text default (concat(d, ' world''s €')),
 	PRIMARY KEY (pk)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 
